@@ -443,7 +443,7 @@ class clientIF(object):
                     raise vm.VolumeError(
                         "Drive %r not visible" % drive["GUID"])
 
-                res = self.irs.appropriateDevice(drive["GUID"], vmId)
+                res = self.irs.appropriateDevice(drive["GUID"], vmId, 'mpath')
                 if res['status']['code']:
                     raise vm.VolumeError(
                         "Cannot appropriate drive %r" % drive["GUID"])
@@ -457,6 +457,10 @@ class clientIF(object):
 
                 volPath = res['path']
 
+            elif "RBD" in drive:
+                res = self.irs.appropriateDevice(drive["RBD"], vmId, 'rbd')
+                volPath = res['path']
+
             # cdrom and floppy drives
             elif (device in ('cdrom', 'floppy') and 'specParams' in drive):
                 params = drive['specParams']
